Error

Enum Error 

pub enum Error {
    EndpointConnection,
    EndpointResponse,
    Endpoint {
        description: String,
    },
}

Variants



EndpointConnection

Cannot request to or read data from the endpoint. It could be a network issue, SSL certificate setup, and more.



EndpointResponse

The endpoint returns data that does not follow specification.



Endpoint

The endpoint reports an error. It could be invalid data from the client or an internal endpoint error. Unfortunately, there are no official error cases. Telegram provides a short description for error handling here.

This variant makes the error not as small as the CPU word. Fortunately, it will not affect the execution time much because there are rate limits for calling the endpoint, see module crate::limit.

Fields

description: String